@@ -2,8 +2,10 @@ from enum import Enum
 from importlib.metadata import version
 import logging
 import os
+import shutil
 from subprocess import Popen
 import sys
+import tempfile
 
 
 logger = logging.getLogger(__name__)
@@ -57,16 +59,14 @@ def get_binary_path():
     return binary_path
 
 
-# Pass package version to binary via environment variable
-def set_package_version():
+def get_package_version():
     try:
         package_version = version("datadog-serverless-compat")
     except Exception as e:
         logger.error(f"Unable to identify package version: {e}")
         package_version = "unknown"
 
-    logger.debug(f"Setting DD_SERVERLESS_COMPAT_VERSION to {package_version}")
-    os.environ["DD_SERVERLESS_COMPAT_VERSION"] = package_version
+    return package_version
 
 
 def start():
@@ -91,7 +91,6 @@ def start():
         return
 
     binary_path = get_binary_path()
-    logger.debug(f"Spawning process from binary at path {binary_path}")
 
     if not os.path.exists(binary_path):
         logger.error(
@@ -99,13 +98,20 @@ def start():
         )
         return
 
-    set_package_version()
+    package_version = get_package_version()
+    logger.debug(f"Found package version {package_version}")
 
     try:
-        logger.debug(
-            f"Trying to spawn the Serverless Compatibility Layer at path: {binary_path}"
-        )
-        Popen(binary_path)
+        temp_dir = os.path.join(tempfile.gettempdir(), "datadog")
+        os.makedirs(temp_dir, exist_ok=True)
+        executable_file_path = os.path.join(temp_dir, os.path.basename(binary_path))
+        shutil.copy2(binary_path, executable_file_path)
+        os.chmod(executable_file_path, 0o744)
+        logger.debug(f"Spawning process from binary at path {executable_file_path}")
+
+        env = os.environ.copy()
+        env["DD_SERVERLESS_COMPAT_VERSION"] = package_version
+        Popen(executable_file_path, env=env)
     except Exception as e:
         logger.error(
             f"An unexpected error occurred while spawning Serverless Compatibility Layer process: {repr(e)}"
